@@ -6,22 +6,10 @@ evaluation of melody extraction algorithms. This collection contains
 64 audio excerpts focused on symphonic music with their corresponding
 annotation of the melody.
 
-Details can be found at https://zenodo.org/record/1289786#.XREpzaeZPx6
-
-
-Attributes:
-    DATA.index (dict): {track_id: track_data}.
-        track_data is a jason data loaded from `index/`
-
-    DIR (str): The directory name for ORCHSET.
-        Set to `'Orchset'`.
-
-    DATA.metadata
+For more details, please visit: https://zenodo.org/record/1289786#.XREpzaeZPx6
 
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+
 import csv
 import glob
 import librosa
@@ -30,17 +18,20 @@ import numpy as np
 import os
 import shutil
 
-import mirdata.utils as utils
-import mirdata.download_utils as download_utils
-import mirdata.jams_utils as jams_utils
+from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
+from mirdata import utils
 
 
-REMOTE = download_utils.RemoteFileMetadata(
-    filename='Orchset_dataset_0.zip',
-    url='https://zenodo.org/record/1289786/files/Orchset_dataset_0.zip?download=1',
-    checksum='cf6fe52d64624f61ee116c752fb318ca',
-    destination_dir=None,
-)
+REMOTES = {
+    'all': download_utils.RemoteFileMetadata(
+        filename='Orchset_dataset_0.zip',
+        url='https://zenodo.org/record/1289786/files/Orchset_dataset_0.zip?download=1',
+        checksum='cf6fe52d64624f61ee116c752fb318ca',
+        destination_dir=None,
+    )
+}
 
 DATASET_DIR = 'Orchset'
 
@@ -108,29 +99,30 @@ def _load_metadata(data_home):
 DATA = utils.LargeData('orchset_index.json', _load_metadata)
 
 
-class Track(object):
-    """ORCHSET Track class
+class Track(track.Track):
+    """orchset Track class
 
     Args:
-        track_id (str): Track id of the Track
-        data_home (str): Local path where the dataset is stored.
+        track_id (str): track id of the track
+        data_home (str): Local path where the dataset is stored. default=None
             If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
-        track_id (str): Track id
-        audio_path_mono (str): Mono audio path of the track
-        audio_path_stereo (str): Stereo audio path of the track
-        composer (str): Composer of the track
-        work (str): The musical work
-        predominant_melodic_instruments ([str]): List of instruments which play the melody
         alternating_melody (bool): True if the melody alternates between instruments
-        contains_winds (bool): True if the track contains any wind instrument
-        contains_strings (bool): True if the track contains any string instrument
+        audio_path_mono (str): path to the mono audio file
+        audio_path_stereo (str): path to the stereo audio file
+        composer (str): the work's composer
         contains_brass (bool): True if the track contains any brass instrument
+        contains_strings (bool): True if the track contains any string instrument
+        contains_winds (bool): True if the track contains any wind instrument
+        excerpt (str): True if the track is an excerpt
+        melody_path (str): path to the melody annotation file
+        only_brass (bool): True if the track contains brass instruments only
         only_strings (bool): True if the track contains string instruments only
         only_winds (bool): True if the track contains wind instruments only
-        only_brass (bool): True if the track contains brass instruments only
-        melody (F0Data): Melody annotation
+        predominant_melodic_instruments (list): List of instruments which play the melody
+        track_id (str): track id
+        work (str): The musical work
 
     """
 
@@ -145,6 +137,7 @@ class Track(object):
 
         self._data_home = data_home
         self._track_paths = DATA.index[track_id]
+        self.melody_path = os.path.join(self._data_home, self._track_paths['melody'][0])
 
         metadata = DATA.metadata(data_home)
         if metadata is not None and track_id in metadata:
@@ -185,66 +178,86 @@ class Track(object):
         self.only_winds = self._track_metadata['only_winds']
         self.only_brass = self._track_metadata['only_brass']
 
-    def __repr__(self):
-        repr_string = (
-            "Orchset Track(track_id={}, audio_path_stereo={}, "
-            + "audio_path_mono={}, composer={}, work={}, excerpt={}, "
-            + "predominant_melodic_instruments={}, alternating_melody={}, "
-            + "contains_winds={}, contains_strings={}, contains_brass={}, "
-            + "only_strings={}, only_winds={}, only_brass={}, "
-            + "melody=F0Data('times', 'frequencies', 'confidence'))"
-        )
-        return repr_string.format(
-            self.track_id,
-            self.audio_path_stereo,
-            self.audio_path_mono,
-            self.composer,
-            self.work,
-            self.excerpt,
-            self.predominant_melodic_instruments,
-            self.alternating_melody,
-            self.contains_winds,
-            self.contains_strings,
-            self.contains_brass,
-            self.only_strings,
-            self.only_winds,
-            self.only_brass,
-        )
-
     @utils.cached_property
     def melody(self):
-        return _load_melody(
-            os.path.join(self._data_home, self._track_paths['melody'][0])
-        )
+        """F0Data: melody annotation"""
+        return load_melody(self.melody_path)
 
     @property
     def audio_mono(self):
-        return librosa.load(self.audio_path_mono, sr=None)
+        """(np.ndarray, float): mono audio signal, sample rate"""
+        return load_audio_mono(self.audio_path_mono)
 
     @property
     def audio_stereo(self):
-        return librosa.load(self.audio_path_stereo, sr=None, mono=False)
+        """(np.ndarray, float): stereo audio signal, sample rate"""
+        return load_audio_stereo(self.audio_path_stereo)
 
     def to_jams(self):
+        """Jams: the track's data in jams format"""
         return jams_utils.jams_converter(
-            f0_data=[(self.melody, None)], metadata=self._track_metadata
+            audio_path=self.audio_path_mono,
+            f0_data=[(self.melody, 'annotated melody')],
+            metadata=self._track_metadata,
         )
 
 
-def download(data_home=None, force_overwrite=False):
+def load_audio_mono(audio_path):
+    """Load a Orchset audio file.
+
+    Args:
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+
+    return librosa.load(audio_path, sr=None, mono=True)
+
+
+def load_audio_stereo(audio_path):
+    """Load a Orchset audio file.
+
+    Args:
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+
+    return librosa.load(audio_path, sr=None, mono=False)
+
+
+def download(data_home=None, force_overwrite=False, cleanup=True):
     """Download ORCHSET Dataset.
 
     Args:
-        data_home (str): Local path where the dataset is stored.
+        data_home (str):
+            Local path where the dataset is stored.
             If `None`, looks for the data in the default directory, `~/mir_datasets`
-        force_overwrite (bool): Whether to overwrite the existing downloaded data
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
 
     """
     if data_home is None:
         data_home = utils.get_default_dataset_path(DATASET_DIR)
 
     download_utils.downloader(
-        data_home, zip_downloads=[REMOTE], force_overwrite=force_overwrite
+        data_home,
+        remotes=None,
+        info_message=None,
+        force_overwrite=force_overwrite,
+        cleanup=cleanup,
     )
 
     # files get downloaded to a folder called Orchset - move everything up a level
@@ -312,9 +325,9 @@ def load(data_home=None):
     return orchset_data
 
 
-def _load_melody(melody_path):
+def load_melody(melody_path):
     if not os.path.exists(melody_path):
-        return None
+        raise IOError("melody_path {} does not exist".format(melody_path))
 
     times = []
     freqs = []
@@ -349,6 +362,7 @@ Classical Music", Journal of New Music Research (2016)
     pages={101--117},
     year={2016},
     publisher={Taylor \\& Francis}
+}
 """
 
     print(cite_data)
